==> scone-0.1.3.tgz: package/scone.js <==
#!/usr/bin/env node

/* 'Scone.js' makes developing node.js apps that use coffeescript and stylus easier by merging the
 *  coffee -w and stylus -w commands along side the server console. One terminal to rule them all.
 *  When you make a change to either .coffee files or .styl files they will be compiled and output immediately.
 *  Scone watches the .js files in your node app and will restart the server whenever it sees a change.
 *  Stylus compiles do not cause the server to restart, it's only css so... just refresh the page.
 *
 *  In order to accomplish this amazing feat Scone expects a few conventions to be followed.
 *
 *  1.) .coffee files are to stored in a /coffee directory in the root of your app, and are compiled to ./
 *  2.) .styl files are kept in a /views/stylus directory and compiled to /public/css
 *
 *
 *  Usage:
 * 
 *    scone 
 *  
 *  Licensed under the terms of MIT License. For the full copyright and license
 *  information, please see the LICENSE file in the root folder.
 *
 * 
 */
(function() {
  var child_process, fs, scone, startitup;
  child_process = require('child_process');
  fs = require('fs');
  scone = {
    process: null,
    files: [],
    restarting: false,
    "coffeewatch": function() {
      var coffee;
      coffee = child_process.exec('coffee -o ' + process.cwd() + ' -w -l -c ' + process.cwd() + '/coffee/*.coffee');
      console.log("Making Coffee");
      coffee.stdout.addListener('data', function(data) {
        var encoding;
        return process.stdout.write(data, encoding = 'utf8');
      });
      return coffee.stderr.addListener('data', function(data) {
        var encoding;
        return process.stdout.write(data, encoding = 'utf8');
      });
    },
    "styluswatch": function() {
      var stylus;
      stylus = child_process.exec('stylus -o ' + process.cwd() + '/public/css -w -c ' + process.cwd() + '/views/stylus');
      console.log("With Styl");
      stylus.stdout.addListener('data', function(data) {
        var encoding;
        return process.stdout.write(data, encoding = 'utf8');
      });
      return stylus.stderr.addListener('data', function(data) {
        var encoding;
        return process.stdout.write(data, encoding = 'utf8');
      });
    },
    "restart": function() {
      this.restarting = true;
      console.log("Stopping server for restart");
      return this.process.kill();
    },
    "start": function() {
      var self;
      self = this;
      console.log('Starting Node App');
      self.watchFiles();
      this.process = child_process.spawn(process.ARGV[0], ['app.js']);
      this.process.stdout.addListener('data', function(data) {
        return process.stdout.write(data);
      });
      this.process.stderr.addListener('data', function(data) {
        return console.log(data);
      });
      return this.process.addListener('exit', function(code) {
        console.log('App Exited: ' + code);
        this.process = null;
        if (self.restarting) {
          self.restarting = true;
          self.unwatchFiles();
          return self.start();
        }
      });
    },
    "watchFiles": function() {
      var self;
      self = this;
      return child_process.exec('find . | grep "\.js$"', function(error, stdout, stderr) {
        var files;
        files = stdout.trim().split("\n");
        return files.forEach(function(file) {
          self.files.push(file);
          return fs.watchFile(file, {
            interval: 500
          }, function(curr, prev) {
            if (curr.mtime.valueOf() !== prev.mtime.valueOf() || curr.ctime.valueOf() !== prev.ctime.valueOf()) {
              console.log('Restarting because of changed file at ' + file);
              return scone.restart();
            }
          });
        });
      });
    },
    "unwatchFiles": function() {
      this.files.forEach(function(file) {
        return fs.unwatchFile(file);
      });
      return this.files = [];
    }
  };
  startitup = function() {
    scone.coffeewatch();
    setTimeout(function() {
      return scone.styluswatch();
    }, 1000);
    return setTimeout(function() {
      return scone.start();
    }, 2000);
  };
  startitup();
}).call(this);

==> scone-0.1.5.tgz: package/scone.js <==
#!/usr/bin/env node
(function() {
  var child_process, fs, scone, startitup;
  child_process = require('child_process');
  fs = require('fs');
  scone = {
    process: null,
    files: [],
    restarting: false,
    "makedir": function(dir) {
      try {
        return fs.statSync(dir);
      } catch (error) {
        return fs.mkdirSync(dir, '0755');
      }
    },
    "appcoffeewatch": function() {
      var appcoffee;
      appcoffee = child_process.exec("coffee -o " + (process.cwd()) + "/app -w -l -c " + (process.cwd()) + "/src/app/**");
      console.log("Making App Coffee");
      return this.captureOutput(appcoffee);
    },
    "viewcoffeewatch": function() {
      var viewcoffee;
      viewcoffee = child_process.exec("coffee -o " + (process.cwd()) + "/public -w -l -c " + (process.cwd()) + "/src/public/**");
      console.log("Making View Coffee");
      return this.captureOutput(viewcoffee);
    },
    "styluswatch": function() {
      var stylus;
      stylus = child_process.exec("stylus -o " + (process.cwd()) + "/public/css -w -c " + (process.cwd()) + "/src/public/css");
      console.log("With Styl");
      return this.captureOutput(stylus);
    },
    captureOutput: function(proc) {
      proc.stdout.addListener('data', function(data) {
        var encoding;
        return process.stdout.write(data, encoding = 'utf8');
      });
      return proc.stderr.addListener('data', function(data) {
        var encoding;
        return process.stdout.write(data, encoding = 'utf8');
      });
    },
    "restart": function() {
      this.restarting = true;
      console.log("Stopping server for restart");
      return this.process.kill();
    },
    "start": function() {
      var self;
      self = this;
      console.log('Starting Node App');
      self.watchFiles();
      this.process = child_process.spawn(process.ARGV[0], ['app/app.js']);
      this.process.stdout.addListener('data', function(data) {
        return process.stdout.write(data);
      });
      this.process.stderr.addListener('data', function(data) {
        return console.log(data);
      });
      return this.process.addListener('exit', function(code) {
        console.log('App Exited: ' + code);
        this.process = null;
        if (self.restarting) {
          self.restarting = true;
          self.unwatchFiles();
          return self.start();
        }
      });
    },
    "watchFiles": function() {
      var self;
      self = this;
      return child_process.exec('find . | grep "\.js$"', function(error, stdout, stderr) {
        var files;
        files = stdout.trim().split("\n");
        return files.forEach(function(file) {
          self.files.push(file);
          return fs.watchFile(file, {
            interval: 500
          }, function(curr, prev) {
            if (curr.mtime.valueOf() !== prev.mtime.valueOf() || curr.ctime.valueOf() !== prev.ctime.valueOf()) {
              console.log('Restarting because of changed file at ' + file);
              return scone.restart();
            }
          });
        });
      });
    },
    "unwatchFiles": function() {
      this.files.forEach(function(file) {
        return fs.unwatchFile(file);
      });
      return this.files = [];
    }
  };
  startitup = function() {
    scone.makedir("app");
    scone.makedir("public");
    scone.makedir("public/js");
    scone.makedir("public/css");
    scone.appcoffeewatch();
    scone.viewcoffeewatch();
    scone.styluswatch();
    return setTimeout(function() {
      return scone.start();
    }, 2000);
  };
  startitup();
}).call(this);
